@@ -1,29 +1,12 @@
 """
-
 Version 2x: https://swagger.io/docs/specification/2-0/basic-structure/
 Version 3x: https://swagger.io/specification
-
 """
 
-# region Compatibility
-
-from __future__ import nested_scopes, generators, division, absolute_import, with_statement, \
-   print_function, unicode_literals
-
-from sob.utilities.compatibility import backport
-
-backport()  # noqa
-
-# endregion
-
 from copy import deepcopy
 from numbers import Number
-
-try:
-    import typing
-    from typing import Union, Any
-except ImportError:
-    typing = Union = Any = None
+import typing
+from typing import Union, Any
 
 import sob
 
@@ -41,23 +24,28 @@ class Object(sob.model.Object):
 _object_hooks = sob.hooks.writable(Object)  # type: hooks.Object
 
 
+def _add_property(self, key):
+    # type: (Object, str) -> None
+    """
+    Look for a matching property, and if none exists--create one
+    """
+    try:
+        self._get_key_property_name(key)
+    except KeyError:
+        meta_ = sob.meta.writable(self)
+        if meta_.properties is None:
+            meta_.properties = sob.meta.Properties()
+        property_name = sob.utilities.property_name(key)
+        meta_.properties[property_name] = sob.properties.Property(name=key)
+
+
 def _object_before_setitem(self, key, value):
     # type: (Object, str, Any) -> Tuple[str, Any]
     """
     This hook allows for the use of extension attributes
     """
-
     if key[:2] == 'x-':
-        # Look for a matching property, and if none exists--create one
-        try:
-            self._get_key_property_name(key)
-        except KeyError:
-            meta_ = sob.meta.writable(self)
-            if meta_.properties is None:
-                meta_.properties = sob.meta.Properties()
-            property_name = sob.utilities.property_name(key)
-            meta_.properties[property_name] = sob.properties.Property(name=key)
-
+        _add_property(self, key)
     return key, value
 
 
@@ -80,26 +68,12 @@ class Reference(Object):
         self,
         _=None,  # type: Optional[typing.Mapping]
         ref=None,  # type: Optional[str]
+        **kwargs
     ):
         self.ref = ref
         super().__init__(_)
-
-
-_reference_hooks = sob.hooks.writable(Reference)
-
-
-def _reference_before_unmarshal(data):
-    # type: (typing.Mapping) -> typing.Mapping
-    """
-    This prevents any attribute except `$ref` from being applied to references
-    """
-    if data and ('$ref' in data):
-        for key in (set(data.keys()) - {'$ref'}):
-            del data[key]
-    return data
-
-
-_reference_hooks.before_unmarshal = _reference_before_unmarshal
+        for key, value in kwargs.items():
+            self[key] = value
 
 
 sob.meta.writable(Reference).properties = [
@@ -107,9 +81,43 @@ sob.meta.writable(Reference).properties = [
 ]
 
 
+_reference_hooks = sob.hooks.writable(Reference)  # type: hooks.Object
+
+
+def _reference_before_setitem(self, key, value):
+    # type: (Object, str, Any) -> Tuple[str, Any]
+    """
+    This hook allows for the use of any arbitrary attribute, as specified in
+    the `patternProperties` for this object in the OpenAPI schema
+    """
+    if key != '$ref':
+        _add_property(self, key)
+    return key, value
+
+
+_reference_hooks.before_setitem = _reference_before_setitem
+
+
+def _reference_after_unmarshal(data):  # noqa
+    # type: (Dict[str, Any]) -> None
+    """
+    This ensures all reference objects have a `$ref` attribute
+    """
+    if data['$ref'] is None:
+        raise TypeError(
+            'All instances of `%s` must have a `$ref` attribute' %
+            sob.utilities.qualified_name(Reference)
+        )
+    return data
+
+
+_reference_hooks.after_unmarshal = _reference_after_unmarshal
+
+
 class Contact(Object):
     """
-    https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md#contactObject
+    https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md
+    #contactObject
     """
 
     def __init__(
@@ -135,7 +143,8 @@ sob.meta.writable(Contact).properties = [
 
 class License(Object):
     """
-    https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md#licenseObject
+    https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.0.md
+    #licenseObject
     """
 
     def __init__(
@@ -446,7 +455,7 @@ class Schema(Object):
         self.links = links
         self.nullable = nullable
         super().__init__(_)
-        
+
 
 # ...definitions are postponed until dependencies are defined
 
